==> chromium-browser-27.0.1453.93.tar.xz: chromium-browser-27.0.1453.93/components/autofill/browser/autofill_regex_constants.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_AUTOFILL_BROWSER_AUTOFILL_REGEX_CONSTANTS_H_
#define COMPONENTS_AUTOFILL_BROWSER_AUTOFILL_REGEX_CONSTANTS_H_

namespace autofill {

extern const char kAttentionIgnoredRe[];
extern const char kRegionIgnoredRe[];
extern const char kCompanyRe[];
extern const char kAddressLine1Re[];
extern const char kAddressLine1LabelRe[];
extern const char kAddressLine2Re[];
extern const char kAddressLine2LabelRe[];
extern const char kAddressLine3Re[];
extern const char kCountryRe[];
extern const char kZipCodeRe[];
extern const char kZip4Re[];
extern const char kCityRe[];
extern const char kStateRe[];
extern const char kAddressTypeSameAsRe[];
extern const char kAddressTypeUseMyRe[];
extern const char kBillingDesignatorRe[];
extern const char kShippingDesignatorRe[];
extern const char kNameOnCardRe[];
extern const char kNameOnCardContextualRe[];
extern const char kCardNumberRe[];
extern const char kCardCvcRe[];
extern const char kCardTypeRe[];
extern const char kExpirationMonthRe[];
extern const char kExpirationYearRe[];
extern const char kExpirationDate2DigitYearRe[];
extern const char kExpirationDateRe[];
extern const char kCardIgnoredRe[];
extern const char kGiftCardRe[];
extern const char kEmailRe[];
extern const char kNameIgnoredRe[];
extern const char kNameRe[];
extern const char kNameSpecificRe[];
extern const char kFirstNameRe[];
extern const char kMiddleInitialRe[];
extern const char kMiddleNameRe[];
extern const char kLastNameRe[];
extern const char kPhoneRe[];
extern const char kCountryCodeRe[];
extern const char kAreaCodeNotextRe[];
extern const char kAreaCodeRe[];
extern const char kFaxRe[];
extern const char kPhonePrefixSeparatorRe[];
extern const char kPhoneSuffixSeparatorRe[];
extern const char kPhonePrefixRe[];
extern const char kPhoneSuffixRe[];
extern const char kPhoneExtensionRe[];

}  // namespace autofill

#endif  // COMPONENTS_AUTOFILL_BROWSER_AUTOFILL_REGEX_CONSTANTS_H_

==> chromium-browser-28.0.1500.45.tar.xz: chromium-browser-28.0.1500.45/components/autofill/browser/autofill_regex_constants.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_AUTOFILL_BROWSER_AUTOFILL_REGEX_CONSTANTS_H_
#define COMPONENTS_AUTOFILL_BROWSER_AUTOFILL_REGEX_CONSTANTS_H_

namespace autofill {

extern const char kAttentionIgnoredRe[];
extern const char kRegionIgnoredRe[];
extern const char kCompanyRe[];
extern const char kAddressLine1Re[];
extern const char kAddressLine1LabelRe[];
extern const char kAddressLine2Re[];
extern const char kAddressLine2LabelRe[];
extern const char kAddressLinesExtraRe[];
extern const char kCountryRe[];
extern const char kZipCodeRe[];
extern const char kZip4Re[];
extern const char kCityRe[];
extern const char kStateRe[];
extern const char kAddressTypeSameAsRe[];
extern const char kAddressTypeUseMyRe[];
extern const char kBillingDesignatorRe[];
extern const char kShippingDesignatorRe[];
extern const char kNameOnCardRe[];
extern const char kNameOnCardContextualRe[];
extern const char kCardNumberRe[];
extern const char kCardCvcRe[];
extern const char kCardTypeRe[];
extern const char kExpirationMonthRe[];
extern const char kExpirationYearRe[];
extern const char kExpirationDate2DigitYearRe[];
extern const char kExpirationDateRe[];
extern const char kCardIgnoredRe[];
extern const char kGiftCardRe[];
extern const char kEmailRe[];
extern const char kNameIgnoredRe[];
extern const char kNameRe[];
extern const char kNameSpecificRe[];
extern const char kFirstNameRe[];
extern const char kMiddleInitialRe[];
extern const char kMiddleNameRe[];
extern const char kLastNameRe[];
extern const char kPhoneRe[];
extern const char kCountryCodeRe[];
extern const char kAreaCodeNotextRe[];
extern const char kAreaCodeRe[];
extern const char kFaxRe[];
extern const char kPhonePrefixSeparatorRe[];
extern const char kPhoneSuffixSeparatorRe[];
extern const char kPhonePrefixRe[];
extern const char kPhoneSuffixRe[];
extern const char kPhoneExtensionRe[];

}  // namespace autofill

#endif  // COMPONENTS_AUTOFILL_BROWSER_AUTOFILL_REGEX_CONSTANTS_H_
